@@ -5,14 +5,12 @@ import (
 	"crypto/tls"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
-	"log"
 	"net"
 	"net/http"
 	"net/url"
+	"os"
 	"os/user"
 	"path/filepath"
-	"sync"
 	"time"
 
 	"github.com/ghodss/yaml"
@@ -42,7 +40,7 @@ const cAdvisorPodListDefaultInterval = 60
 // loadClient parses a kubeconfig from a file and returns a Kubernetes
 // client. It does not support extensions or client auth providers.
 func loadClient(kubeconfigPath string) (*kubernetes.Clientset, error) {
-	data, err := ioutil.ReadFile(kubeconfigPath)
+	data, err := os.ReadFile(kubeconfigPath)
 	if err != nil {
 		return nil, fmt.Errorf("failed reading '%s': %v", kubeconfigPath, err)
 	}
@@ -55,7 +53,7 @@ func loadClient(kubeconfigPath string) (*kubernetes.Clientset, error) {
 	return kubernetes.NewForConfig(&config)
 }
 
-func (p *Prometheus) start(ctx context.Context) error {
+func (p *Prometheus) startK8s(ctx context.Context) error {
 	config, err := rest.InClusterConfig()
 	if err != nil {
 		return fmt.Errorf("failed to get InClusterConfig - %v", err)
@@ -77,8 +75,6 @@ func (p *Prometheus) start(ctx context.Context) error {
 		}
 	}
 
-	p.wg = sync.WaitGroup{}
-
 	p.wg.Add(1)
 	go func() {
 		defer p.wg.Done()
@@ -114,47 +110,54 @@ func (p *Prometheus) watchPod(ctx context.Context, client *kubernetes.Clientset)
 		LabelSelector: p.KubernetesLabelSelector,
 		FieldSelector: p.KubernetesFieldSelector,
 	})
+	defer watcher.Stop()
 	if err != nil {
 		return err
 	}
-	pod := &corev1.Pod{}
-	go func() {
-		for event := range watcher.ResultChan() {
-			pod = &corev1.Pod{}
-			// If the pod is not "ready", there will be no ip associated with it.
-			if pod.Annotations["prometheus.io/scrape"] != "true" ||
-				!podReady(pod.Status.ContainerStatuses) {
-				continue
-			}
 
-			switch event.Type {
-			case watch.Added:
-				registerPod(pod, p)
-			case watch.Modified:
-				// To avoid multiple actions for each event, unregister on the first event
-				// in the delete sequence, when the containers are still "ready".
-				if pod.GetDeletionTimestamp() != nil {
-					unregisterPod(pod, p)
-				} else {
+	for {
+		select {
+		case <-ctx.Done():
+			return nil
+		default:
+			for event := range watcher.ResultChan() {
+				pod, ok := event.Object.(*corev1.Pod)
+				if !ok {
+					return fmt.Errorf("Unexpected object when getting pods")
+				}
+
+				// If the pod is not "ready", there will be no ip associated with it.
+				if pod.Annotations["prometheus.io/scrape"] != "true" ||
+					!podReady(pod.Status.ContainerStatuses) {
+					continue
+				}
+
+				switch event.Type {
+				case watch.Added:
 					registerPod(pod, p)
+				case watch.Modified:
+					// To avoid multiple actions for each event, unregister on the first event
+					// in the delete sequence, when the containers are still "ready".
+					if pod.GetDeletionTimestamp() != nil {
+						unregisterPod(pod, p)
+					} else {
+						registerPod(pod, p)
+					}
 				}
 			}
 		}
-	}()
-
-	return nil
+	}
 }
 
 func (p *Prometheus) cAdvisor(ctx context.Context, bearerToken string) error {
 	// The request will be the same each time
 	podsURL := fmt.Sprintf("https://%s:10250/pods", p.NodeIP)
 	req, err := http.NewRequest("GET", podsURL, nil)
-	req.Header.Set("Authorization", "Bearer "+bearerToken)
-	req.Header.Add("Accept", "application/json")
-
 	if err != nil {
 		return fmt.Errorf("error when creating request to %s to get pod list: %w", podsURL, err)
 	}
+	req.Header.Set("Authorization", "Bearer "+bearerToken)
+	req.Header.Add("Accept", "application/json")
 
 	// Update right away so code is not waiting the length of the specified scrape interval initially
 	err = updateCadvisorPodList(p, req)
@@ -291,12 +294,15 @@ func registerPod(pod *corev1.Pod, p *Prometheus) {
 	if p.kubernetesPods == nil {
 		p.kubernetesPods = map[string]URLAndAddress{}
 	}
-	targetURL := getScrapeURL(pod)
-	if targetURL == nil {
+	targetURL, err := getScrapeURL(pod)
+	if err != nil {
+		p.Log.Errorf("could not parse URL: %s", err)
+		return
+	} else if targetURL == nil {
 		return
 	}
 
-	log.Printf("D! [inputs.prometheus] will scrape metrics from %q", *targetURL)
+	p.Log.Debugf("will scrape metrics from %q", targetURL.String())
 	// add annotation as metrics tags
 	tags := pod.Annotations
 	if tags == nil {
@@ -308,12 +314,7 @@ func registerPod(pod *corev1.Pod, p *Prometheus) {
 	for k, v := range pod.Labels {
 		tags[k] = v
 	}
-	URL, err := url.Parse(*targetURL)
-	if err != nil {
-		log.Printf("E! [inputs.prometheus] could not parse URL %q: %s", *targetURL, err.Error())
-		return
-	}
-	podURL := p.AddressToURL(URL, URL.Hostname())
+	podURL := p.AddressToURL(targetURL, targetURL.Hostname())
 
 	// Locks earlier if using cAdvisor calls - makes a new list each time
 	// rather than updating and removing from the same list
@@ -323,22 +324,22 @@ func registerPod(pod *corev1.Pod, p *Prometheus) {
 	}
 	p.kubernetesPods[podURL.String()] = URLAndAddress{
 		URL:         podURL,
-		Address:     URL.Hostname(),
-		OriginalURL: URL,
+		Address:     targetURL.Hostname(),
+		OriginalURL: targetURL,
 		Tags:        tags,
 	}
 }
 
-func getScrapeURL(pod *corev1.Pod) *string {
+func getScrapeURL(pod *corev1.Pod) (*url.URL, error) {
 	ip := pod.Status.PodIP
 	if ip == "" {
 		// return as if scrape was disabled, we will be notified again once the pod
 		// has an IP
-		return nil
+		return nil, nil
 	}
 
 	scheme := pod.Annotations["prometheus.io/scheme"]
-	path := pod.Annotations["prometheus.io/path"]
+	pathAndQuery := pod.Annotations["prometheus.io/path"]
 	port := pod.Annotations["prometheus.io/port"]
 
 	if scheme == "" {
@@ -347,34 +348,36 @@ func getScrapeURL(pod *corev1.Pod) *string {
 	if port == "" {
 		port = "9102"
 	}
-	if path == "" {
-		path = "/metrics"
+	if pathAndQuery == "" {
+		pathAndQuery = "/metrics"
 	}
 
-	u := &url.URL{
-		Scheme: scheme,
-		Host:   net.JoinHostPort(ip, port),
-		Path:   path,
+	base, err := url.Parse(pathAndQuery)
+	if err != nil {
+		return nil, err
 	}
 
-	x := u.String()
+	base.Scheme = scheme
+	base.Host = net.JoinHostPort(ip, port)
 
-	return &x
+	return base, nil
 }
 
 func unregisterPod(pod *corev1.Pod, p *Prometheus) {
-	url := getScrapeURL(pod)
-	if url == nil {
+	targetURL, err := getScrapeURL(pod)
+	if err != nil {
+		p.Log.Errorf("failed to parse url: %s", err)
+		return
+	} else if targetURL == nil {
 		return
 	}
 
-	log.Printf("D! [inputs.prometheus] registered a delete request for %q in namespace %q",
-		pod.Name, pod.Namespace)
+	p.Log.Debugf("registered a delete request for %q in namespace %q", pod.Name, pod.Namespace)
 
 	p.lock.Lock()
 	defer p.lock.Unlock()
-	if _, ok := p.kubernetesPods[*url]; ok {
-		delete(p.kubernetesPods, *url)
-		log.Printf("D! [inputs.prometheus] will stop scraping for %q", *url)
+	if _, ok := p.kubernetesPods[targetURL.String()]; ok {
+		delete(p.kubernetesPods, targetURL.String())
+		p.Log.Debugf("will stop scraping for %q", targetURL.String())
 	}
 }
