@@ -5,11 +5,12 @@ import (
 	"testing"
 	"time"
 
-	"github.com/influxdata/telegraf/internal"
-	"github.com/influxdata/telegraf/testutil"
 	riemanngo "github.com/riemann/riemann-go-client"
 	"github.com/stretchr/testify/require"
 	"gotest.tools/assert"
+
+	"github.com/influxdata/telegraf/config"
+	"github.com/influxdata/telegraf/testutil"
 )
 
 func TestSocketListener_tcp(t *testing.T) {
@@ -18,17 +19,17 @@ func TestSocketListener_tcp(t *testing.T) {
 	sl := newRiemannSocketListener()
 	sl.Log = testutil.Logger{}
 	sl.ServiceAddress = "tcp://127.0.0.1:5555"
-	sl.ReadBufferSize = internal.Size{Size: 1024}
+	sl.ReadBufferSize = config.Size(1024)
 
 	acc := &testutil.Accumulator{}
 	err := sl.Start(acc)
 	require.NoError(t, err)
 	defer sl.Stop()
 
-	testStats(t, sl)
-	testMissingService(t, sl)
+	testStats(t)
+	testMissingService(t)
 }
-func testStats(t *testing.T, sl *RiemannSocketListener) {
+func testStats(t *testing.T) {
 	c := riemanngo.NewTCPClient("127.0.0.1:5555", 5*time.Second)
 	err := c.Connect()
 	if err != nil {
@@ -40,9 +41,8 @@ func testStats(t *testing.T, sl *RiemannSocketListener) {
 		Service: "hello",
 	})
 	assert.Equal(t, result.GetOk(), true)
-
 }
-func testMissingService(t *testing.T, sl *RiemannSocketListener) {
+func testMissingService(t *testing.T) {
 	c := riemanngo.NewTCPClient("127.0.0.1:5555", 5*time.Second)
 	err := c.Connect()
 	if err != nil {
@@ -51,5 +51,4 @@ func testMissingService(t *testing.T, sl *RiemannSocketListener) {
 	defer c.Close()
 	result, err := riemanngo.SendEvent(c, &riemanngo.Event{})
 	assert.Equal(t, result.GetOk(), false)
-
 }
