@@ -9,7 +9,6 @@ import (
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
-	"github.com/influxdata/telegraf/internal"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
@@ -61,7 +60,7 @@ func TestConcurrentConns(t *testing.T) {
 	// Connection over the limit:
 	conn, err := net.Dial("tcp", "127.0.0.1:8125")
 	assert.NoError(t, err)
-	net.Dial("tcp", "127.0.0.1:8125")
+	_, err = net.Dial("tcp", "127.0.0.1:8125")
 	assert.NoError(t, err)
 	_, err = conn.Write([]byte(testMsg))
 	assert.NoError(t, err)
@@ -90,7 +89,7 @@ func TestConcurrentConns1(t *testing.T) {
 	// Connection over the limit:
 	conn, err := net.Dial("tcp", "127.0.0.1:8125")
 	assert.NoError(t, err)
-	net.Dial("tcp", "127.0.0.1:8125")
+	_, err = net.Dial("tcp", "127.0.0.1:8125")
 	assert.NoError(t, err)
 	_, err = conn.Write([]byte(testMsg))
 	assert.NoError(t, err)
@@ -132,16 +131,11 @@ func BenchmarkUDP(b *testing.B) {
 
 	// send multiple messages to socket
 	for n := 0; n < b.N; n++ {
-		err := listener.Start(acc)
-		if err != nil {
-			panic(err)
-		}
+		require.NoError(b, listener.Start(acc))
 
 		time.Sleep(time.Millisecond * 250)
 		conn, err := net.Dial("udp", "127.0.0.1:8125")
-		if err != nil {
-			panic(err)
-		}
+		require.NoError(b, err)
 
 		var wg sync.WaitGroup
 		for i := 1; i <= producerThreads; i++ {
@@ -152,7 +146,6 @@ func BenchmarkUDP(b *testing.B) {
 
 		// wait for 250,000 metrics to get added to accumulator
 		for len(listener.in) > 0 {
-			fmt.Printf("Left in buffer: %v \n", len(listener.in))
 			time.Sleep(time.Millisecond)
 		}
 		listener.Stop()
@@ -162,6 +155,7 @@ func BenchmarkUDP(b *testing.B) {
 func sendRequests(conn net.Conn, wg *sync.WaitGroup) {
 	defer wg.Done()
 	for i := 0; i < 25000; i++ {
+		//nolint:errcheck,revive
 		fmt.Fprintf(conn, testMsg)
 	}
 }
@@ -179,16 +173,12 @@ func BenchmarkTCP(b *testing.B) {
 
 	// send multiple messages to socket
 	for n := 0; n < b.N; n++ {
-		err := listener.Start(acc)
-		if err != nil {
-			panic(err)
-		}
+		require.NoError(b, listener.Start(acc))
 
 		time.Sleep(time.Millisecond * 250)
 		conn, err := net.Dial("tcp", "127.0.0.1:8125")
-		if err != nil {
-			panic(err)
-		}
+		require.NoError(b, err)
+
 		var wg sync.WaitGroup
 		for i := 1; i <= producerThreads; i++ {
 			wg.Add(1)
@@ -215,10 +205,7 @@ func TestParse_ValidLines(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoError(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 }
 
@@ -246,10 +233,7 @@ func TestParse_Gauges(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	validations := []struct {
@@ -291,10 +275,7 @@ func TestParse_Gauges(t *testing.T) {
 	}
 
 	for _, test := range validations {
-		err := testValidateGauge(test.name, test.value, s.gauges)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateGauge(test.name, test.value, s.gauges))
 	}
 }
 
@@ -324,10 +305,7 @@ func TestParse_Sets(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	validations := []struct {
@@ -353,10 +331,7 @@ func TestParse_Sets(t *testing.T) {
 	}
 
 	for _, test := range validations {
-		err := testValidateSet(test.name, test.value, s.sets)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateSet(test.name, test.value, s.sets))
 	}
 }
 
@@ -381,10 +356,7 @@ func TestParse_Counters(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	validations := []struct {
@@ -418,17 +390,14 @@ func TestParse_Counters(t *testing.T) {
 	}
 
 	for _, test := range validations {
-		err := testValidateCounter(test.name, test.value, s.counters)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateCounter(test.name, test.value, s.counters))
 	}
 }
 
 // Tests low-level functionality of timings
 func TestParse_Timings(t *testing.T) {
 	s := NewTestStatsd()
-	s.Percentiles = []internal.Number{{Value: 90.0}}
+	s.Percentiles = []Number{90.0}
 	acc := &testutil.Accumulator{}
 
 	// Test that timings work
@@ -441,13 +410,10 @@ func TestParse_Timings(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
-	s.Gather(acc)
+	require.NoError(t, s.Gather(acc))
 
 	valid := map[string]interface{}{
 		"90_percentile": float64(11),
@@ -478,13 +444,10 @@ func TestParse_Distributions(t *testing.T) {
 		}
 
 		for _, line := range validLines {
-			err := s.parseStatsdLine(line)
-			if err != nil {
-				t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-			}
+			require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 		}
 
-		s.Gather(acc)
+		require.NoError(t, s.Gather(acc))
 	}
 
 	validMeasurementMap := map[string]float64{
@@ -528,10 +491,7 @@ func TestParseScientificNotation(t *testing.T) {
 		"scientific.notation:4.6968460083008E-5|h",
 	}
 	for _, line := range sciNotationLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line [%s] should not have resulted in error: %s\n", line, err)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line [%s] should not have resulted in error", line)
 	}
 }
 
@@ -550,10 +510,7 @@ func TestParse_InvalidLines(t *testing.T) {
 		"invalid.value:1d1|c",
 	}
 	for _, line := range invalidLines {
-		err := s.parseStatsdLine(line)
-		if err == nil {
-			t.Errorf("Parsing line %s should have resulted in an error\n", line)
-		}
+		require.Errorf(t, s.parseStatsdLine(line), "Parsing line %s should have resulted in an error", line)
 	}
 }
 
@@ -568,10 +525,7 @@ func TestParse_InvalidSampleRate(t *testing.T) {
 	}
 
 	for _, line := range invalidLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	counterValidations := []struct {
@@ -592,21 +546,12 @@ func TestParse_InvalidSampleRate(t *testing.T) {
 	}
 
 	for _, test := range counterValidations {
-		err := testValidateCounter(test.name, test.value, test.cache)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateCounter(test.name, test.value, test.cache))
 	}
 
-	err := testValidateGauge("invalid_sample_rate", 45, s.gauges)
-	if err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateGauge("invalid_sample_rate", 45, s.gauges))
 
-	err = testValidateSet("invalid_sample_rate", 1, s.sets)
-	if err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateSet("invalid_sample_rate", 1, s.sets))
 }
 
 // Names should be parsed like . -> _
@@ -618,10 +563,7 @@ func TestParse_DefaultNameParsing(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	validations := []struct {
@@ -639,10 +581,7 @@ func TestParse_DefaultNameParsing(t *testing.T) {
 	}
 
 	for _, test := range validations {
-		err := testValidateCounter(test.name, test.value, s.counters)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateCounter(test.name, test.value, s.counters))
 	}
 }
 
@@ -659,10 +598,7 @@ func TestParse_Template(t *testing.T) {
 	}
 
 	for _, line := range lines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	validations := []struct {
@@ -681,10 +617,7 @@ func TestParse_Template(t *testing.T) {
 
 	// Validate counters
 	for _, test := range validations {
-		err := testValidateCounter(test.name, test.value, s.counters)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateCounter(test.name, test.value, s.counters))
 	}
 }
 
@@ -701,10 +634,7 @@ func TestParse_TemplateFilter(t *testing.T) {
 	}
 
 	for _, line := range lines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	validations := []struct {
@@ -723,10 +653,7 @@ func TestParse_TemplateFilter(t *testing.T) {
 
 	// Validate counters
 	for _, test := range validations {
-		err := testValidateCounter(test.name, test.value, s.counters)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateCounter(test.name, test.value, s.counters))
 	}
 }
 
@@ -743,10 +670,7 @@ func TestParse_TemplateSpecificity(t *testing.T) {
 	}
 
 	for _, line := range lines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	validations := []struct {
@@ -761,10 +685,7 @@ func TestParse_TemplateSpecificity(t *testing.T) {
 
 	// Validate counters
 	for _, test := range validations {
-		err := testValidateCounter(test.name, test.value, s.counters)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateCounter(test.name, test.value, s.counters))
 	}
 }
 
@@ -791,10 +712,7 @@ func TestParse_TemplateFields(t *testing.T) {
 	}
 
 	for _, line := range lines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	counterTests := []struct {
@@ -820,10 +738,7 @@ func TestParse_TemplateFields(t *testing.T) {
 	}
 	// Validate counters
 	for _, test := range counterTests {
-		err := testValidateCounter(test.name, test.value, s.counters, test.field)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateCounter(test.name, test.value, s.counters, test.field))
 	}
 
 	gaugeTests := []struct {
@@ -844,10 +759,7 @@ func TestParse_TemplateFields(t *testing.T) {
 	}
 	// Validate gauges
 	for _, test := range gaugeTests {
-		err := testValidateGauge(test.name, test.value, s.gauges, test.field)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateGauge(test.name, test.value, s.gauges, test.field))
 	}
 
 	setTests := []struct {
@@ -868,10 +780,7 @@ func TestParse_TemplateFields(t *testing.T) {
 	}
 	// Validate sets
 	for _, test := range setTests {
-		err := testValidateSet(test.name, test.value, s.sets, test.field)
-		if err != nil {
-			t.Error(err.Error())
-		}
+		require.NoError(t, testValidateSet(test.name, test.value, s.sets, test.field))
 	}
 }
 
@@ -919,18 +828,12 @@ func TestParse_Tags(t *testing.T) {
 
 	for _, test := range tests {
 		name, _, tags := s.parseName(test.bucket)
-		if name != test.name {
-			t.Errorf("Expected: %s, got %s", test.name, name)
-		}
+		require.Equalf(t, name, test.name, "Expected: %s, got %s", test.name, name)
 
 		for k, v := range test.tags {
 			actual, ok := tags[k]
-			if !ok {
-				t.Errorf("Expected key: %s not found", k)
-			}
-			if actual != v {
-				t.Errorf("Expected %s, got %s", v, actual)
-			}
+			require.Truef(t, ok, "Expected key: %s not found", k)
+			require.Equalf(t, actual, v, "Expected %s, got %s", v, actual)
 		}
 	}
 }
@@ -1045,10 +948,8 @@ func TestParse_DataDogTags(t *testing.T) {
 			s := NewTestStatsd()
 			s.DataDogExtensions = true
 
-			err := s.parseStatsdLine(tt.line)
-			require.NoError(t, err)
-			err = s.Gather(&acc)
-			require.NoError(t, err)
+			require.NoError(t, s.parseStatsdLine(tt.line))
+			require.NoError(t, s.Gather(&acc))
 
 			testutil.RequireMetricsEqual(t, tt.expected, acc.GetTelegrafMetrics(),
 				testutil.SortMetrics(), testutil.IgnoreTime())
@@ -1080,9 +981,7 @@ func TestParseName(t *testing.T) {
 
 	for _, test := range tests {
 		name, _, _ := s.parseName(test.inName)
-		if name != test.outName {
-			t.Errorf("Expected: %s, got %s", test.outName, name)
-		}
+		require.Equalf(t, name, test.outName, "Expected: %s, got %s", test.outName, name)
 	}
 
 	// Test with separator == "."
@@ -1108,9 +1007,7 @@ func TestParseName(t *testing.T) {
 
 	for _, test := range tests {
 		name, _, _ := s.parseName(test.inName)
-		if name != test.outName {
-			t.Errorf("Expected: %s, got %s", test.outName, name)
-		}
+		require.Equalf(t, name, test.outName, "Expected: %s, got %s", test.outName, name)
 	}
 }
 
@@ -1126,15 +1023,10 @@ func TestParse_MeasurementsWithSameName(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
-	if len(s.counters) != 2 {
-		t.Errorf("Expected 2 separate measurements, found %d", len(s.counters))
-	}
+	require.Lenf(t, s.counters, 2, "Expected 2 separate measurements, found %d", len(s.counters))
 }
 
 // Test that the metric caches expire (clear) an entry after the entry hasn't been updated for the configurable MaxTTL duration.
@@ -1143,8 +1035,8 @@ func TestCachesExpireAfterMaxTTL(t *testing.T) {
 	s.MaxTTL = config.Duration(100 * time.Microsecond)
 
 	acc := &testutil.Accumulator{}
-	s.parseStatsdLine("valid:45|c")
-	s.parseStatsdLine("valid:45|c")
+	require.NoError(t, s.parseStatsdLine("valid:45|c"))
+	require.NoError(t, s.parseStatsdLine("valid:45|c"))
 	require.NoError(t, s.Gather(acc))
 
 	// Max TTL goes by, our 'valid' entry is cleared.
@@ -1152,9 +1044,12 @@ func TestCachesExpireAfterMaxTTL(t *testing.T) {
 	require.NoError(t, s.Gather(acc))
 
 	// Now when we gather, we should have a counter that is reset to zero.
-	s.parseStatsdLine("valid:45|c")
+	require.NoError(t, s.parseStatsdLine("valid:45|c"))
 	require.NoError(t, s.Gather(acc))
 
+	// Wait for the metrics to arrive
+	acc.Wait(3)
+
 	testutil.RequireMetricsEqual(t,
 		[]telegraf.Metric{
 			testutil.MustMetric(
@@ -1238,92 +1133,52 @@ func TestParse_MeasurementsWithMultipleValues(t *testing.T) {
 	sMultiple := NewTestStatsd()
 
 	for _, line := range singleLines {
-		err := sSingle.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, sSingle.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
 	for _, line := range multipleLines {
-		err := sMultiple.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, sMultiple.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
 
-	if len(sSingle.timings) != 3 {
-		t.Errorf("Expected 3 measurement, found %d", len(sSingle.timings))
-	}
+	require.Lenf(t, sSingle.timings, 3, "Expected 3 measurement, found %d", len(sSingle.timings))
 
-	if cachedtiming, ok := sSingle.timings["metric_type=timingvalid_multiple"]; !ok {
-		t.Errorf("Expected cached measurement with hash 'metric_type=timingvalid_multiple' not found")
-	} else {
-		if cachedtiming.name != "valid_multiple" {
-			t.Errorf("Expected the name to be 'valid_multiple', got %s", cachedtiming.name)
-		}
+	cachedtiming, ok := sSingle.timings["metric_type=timingvalid_multiple"]
+	require.Truef(t, ok, "Expected cached measurement with hash 'metric_type=timingvalid_multiple' not found")
+	require.Equalf(t, cachedtiming.name, "valid_multiple", "Expected the name to be 'valid_multiple', got %s", cachedtiming.name)
 
-		// A 0 at samplerate 0.1 will add 10 values of 0,
-		// A 0 with invalid samplerate will add a single 0,
-		// plus the last bit of value 1
-		// which adds up to 12 individual datapoints to be cached
-		if cachedtiming.fields[defaultFieldName].n != 12 {
-			t.Errorf("Expected 12 additions, got %d", cachedtiming.fields[defaultFieldName].n)
-		}
+	// A 0 at samplerate 0.1 will add 10 values of 0,
+	// A 0 with invalid samplerate will add a single 0,
+	// plus the last bit of value 1
+	// which adds up to 12 individual datapoints to be cached
+	require.EqualValuesf(t, cachedtiming.fields[defaultFieldName].n, 12, "Expected 12 additions, got %d", cachedtiming.fields[defaultFieldName].n)
 
-		if cachedtiming.fields[defaultFieldName].upper != 1 {
-			t.Errorf("Expected max input to be 1, got %f", cachedtiming.fields[defaultFieldName].upper)
-		}
-	}
+	require.EqualValuesf(t, cachedtiming.fields[defaultFieldName].upper, 1, "Expected max input to be 1, got %f", cachedtiming.fields[defaultFieldName].upper)
 
 	// test if sSingle and sMultiple did compute the same stats for valid.multiple.duplicate
-	if err := testValidateSet("valid_multiple_duplicate", 2, sSingle.sets); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateSet("valid_multiple_duplicate", 2, sSingle.sets))
 
-	if err := testValidateSet("valid_multiple_duplicate", 2, sMultiple.sets); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateSet("valid_multiple_duplicate", 2, sMultiple.sets))
 
-	if err := testValidateCounter("valid_multiple_duplicate", 5, sSingle.counters); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateCounter("valid_multiple_duplicate", 5, sSingle.counters))
 
-	if err := testValidateCounter("valid_multiple_duplicate", 5, sMultiple.counters); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateCounter("valid_multiple_duplicate", 5, sMultiple.counters))
 
-	if err := testValidateGauge("valid_multiple_duplicate", 1, sSingle.gauges); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateGauge("valid_multiple_duplicate", 1, sSingle.gauges))
 
-	if err := testValidateGauge("valid_multiple_duplicate", 1, sMultiple.gauges); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateGauge("valid_multiple_duplicate", 1, sMultiple.gauges))
 
 	// test if sSingle and sMultiple did compute the same stats for valid.multiple.mixed
-	if err := testValidateSet("valid_multiple_mixed", 1, sSingle.sets); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateSet("valid_multiple_mixed", 1, sSingle.sets))
 
-	if err := testValidateSet("valid_multiple_mixed", 1, sMultiple.sets); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateSet("valid_multiple_mixed", 1, sMultiple.sets))
 
-	if err := testValidateCounter("valid_multiple_mixed", 1, sSingle.counters); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateCounter("valid_multiple_mixed", 1, sSingle.counters))
 
-	if err := testValidateCounter("valid_multiple_mixed", 1, sMultiple.counters); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateCounter("valid_multiple_mixed", 1, sMultiple.counters))
 
-	if err := testValidateGauge("valid_multiple_mixed", 1, sSingle.gauges); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateGauge("valid_multiple_mixed", 1, sSingle.gauges))
 
-	if err := testValidateGauge("valid_multiple_mixed", 1, sMultiple.gauges); err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateGauge("valid_multiple_mixed", 1, sMultiple.gauges))
 }
 
 // Tests low-level functionality of timings when multiple fields is enabled
@@ -1331,7 +1186,7 @@ func TestParse_MeasurementsWithMultipleValues(t *testing.T) {
 func TestParse_TimingsMultipleFieldsWithTemplate(t *testing.T) {
 	s := NewTestStatsd()
 	s.Templates = []string{"measurement.field"}
-	s.Percentiles = []internal.Number{{Value: 90.0}}
+	s.Percentiles = []Number{90.0}
 	acc := &testutil.Accumulator{}
 
 	validLines := []string{
@@ -1348,12 +1203,9 @@ func TestParse_TimingsMultipleFieldsWithTemplate(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
-	s.Gather(acc)
+	require.NoError(t, s.Gather(acc))
 
 	valid := map[string]interface{}{
 		"success_90_percentile": float64(11),
@@ -1382,7 +1234,7 @@ func TestParse_TimingsMultipleFieldsWithTemplate(t *testing.T) {
 func TestParse_TimingsMultipleFieldsWithoutTemplate(t *testing.T) {
 	s := NewTestStatsd()
 	s.Templates = []string{}
-	s.Percentiles = []internal.Number{{Value: 90.0}}
+	s.Percentiles = []Number{90.0}
 	acc := &testutil.Accumulator{}
 
 	validLines := []string{
@@ -1399,12 +1251,9 @@ func TestParse_TimingsMultipleFieldsWithoutTemplate(t *testing.T) {
 	}
 
 	for _, line := range validLines {
-		err := s.parseStatsdLine(line)
-		if err != nil {
-			t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-		}
+		require.NoErrorf(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 	}
-	s.Gather(acc)
+	require.NoError(t, s.Gather(acc))
 
 	expectedSuccess := map[string]interface{}{
 		"90_percentile": float64(11),
@@ -1563,23 +1412,15 @@ func TestParse_Timings_Delete(t *testing.T) {
 	s := NewTestStatsd()
 	s.DeleteTimings = true
 	fakeacc := &testutil.Accumulator{}
-	var err error
 
 	line := "timing:100|ms"
-	err = s.parseStatsdLine(line)
-	if err != nil {
-		t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-	}
+	require.NoError(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 
-	if len(s.timings) != 1 {
-		t.Errorf("Should be 1 timing, found %d", len(s.timings))
-	}
+	require.Lenf(t, s.timings, 1, "Should be 1 timing, found %d", len(s.timings))
 
-	s.Gather(fakeacc)
+	require.NoError(t, s.Gather(fakeacc))
 
-	if len(s.timings) != 0 {
-		t.Errorf("All timings should have been deleted, found %d", len(s.timings))
-	}
+	require.Lenf(t, s.timings, 0, "All timings should have been deleted, found %d", len(s.timings))
 }
 
 // Tests the delete_gauges option
@@ -1587,25 +1428,15 @@ func TestParse_Gauges_Delete(t *testing.T) {
 	s := NewTestStatsd()
 	s.DeleteGauges = true
 	fakeacc := &testutil.Accumulator{}
-	var err error
 
 	line := "current.users:100|g"
-	err = s.parseStatsdLine(line)
-	if err != nil {
-		t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-	}
+	require.NoError(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 
-	err = testValidateGauge("current_users", 100, s.gauges)
-	if err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateGauge("current_users", 100, s.gauges))
 
-	s.Gather(fakeacc)
+	require.NoError(t, s.Gather(fakeacc))
 
-	err = testValidateGauge("current_users", 100, s.gauges)
-	if err == nil {
-		t.Error("current_users_gauge metric should have been deleted")
-	}
+	require.Error(t, testValidateGauge("current_users", 100, s.gauges), "current_users_gauge metric should have been deleted")
 }
 
 // Tests the delete_sets option
@@ -1613,25 +1444,15 @@ func TestParse_Sets_Delete(t *testing.T) {
 	s := NewTestStatsd()
 	s.DeleteSets = true
 	fakeacc := &testutil.Accumulator{}
-	var err error
 
 	line := "unique.user.ids:100|s"
-	err = s.parseStatsdLine(line)
-	if err != nil {
-		t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-	}
+	require.NoError(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error", line)
 
-	err = testValidateSet("unique_user_ids", 1, s.sets)
-	if err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateSet("unique_user_ids", 1, s.sets))
 
-	s.Gather(fakeacc)
+	require.NoError(t, s.Gather(fakeacc))
 
-	err = testValidateSet("unique_user_ids", 1, s.sets)
-	if err == nil {
-		t.Error("unique_user_ids_set metric should have been deleted")
-	}
+	require.Error(t, testValidateSet("unique_user_ids", 1, s.sets), "unique_user_ids_set metric should have been deleted")
 }
 
 // Tests the delete_counters option
@@ -1639,43 +1460,25 @@ func TestParse_Counters_Delete(t *testing.T) {
 	s := NewTestStatsd()
 	s.DeleteCounters = true
 	fakeacc := &testutil.Accumulator{}
-	var err error
 
 	line := "total.users:100|c"
-	err = s.parseStatsdLine(line)
-	if err != nil {
-		t.Errorf("Parsing line %s should not have resulted in an error\n", line)
-	}
+	require.NoError(t, s.parseStatsdLine(line), "Parsing line %s should not have resulted in an error\n", line)
 
-	err = testValidateCounter("total_users", 100, s.counters)
-	if err != nil {
-		t.Error(err.Error())
-	}
+	require.NoError(t, testValidateCounter("total_users", 100, s.counters))
 
-	s.Gather(fakeacc)
+	require.NoError(t, s.Gather(fakeacc))
 
-	err = testValidateCounter("total_users", 100, s.counters)
-	if err == nil {
-		t.Error("total_users_counter metric should have been deleted")
-	}
+	require.Error(t, testValidateCounter("total_users", 100, s.counters), "total_users_counter metric should have been deleted")
 }
 
 func TestParseKeyValue(t *testing.T) {
 	k, v := parseKeyValue("foo=bar")
-	if k != "foo" {
-		t.Errorf("Expected %s, got %s", "foo", k)
-	}
-	if v != "bar" {
-		t.Errorf("Expected %s, got %s", "bar", v)
-	}
+	require.Equalf(t, k, "foo", "Expected %s, got %s", "foo", k)
+	require.Equalf(t, v, "bar", "Expected %s, got %s", "bar", v)
 
 	k2, v2 := parseKeyValue("baz")
-	if k2 != "" {
-		t.Errorf("Expected %s, got %s", "", k2)
-	}
-	if v2 != "baz" {
-		t.Errorf("Expected %s, got %s", "baz", v2)
-	}
+	require.Equalf(t, k2, "", "Expected %s, got %s", "", k2)
+	require.Equalf(t, v2, "baz", "Expected %s, got %s", "baz", v2)
 }
 
 // Test utility functions
@@ -1789,12 +1592,10 @@ func TestTCP(t *testing.T) {
 	conn, err := net.Dial("tcp", addr)
 	_, err = conn.Write([]byte("cpu.time_idle:42|c\n"))
 	require.NoError(t, err)
-	err = conn.Close()
-	require.NoError(t, err)
+	require.NoError(t, conn.Close())
 
 	for {
-		err = statsd.Gather(&acc)
-		require.NoError(t, err)
+		require.NoError(t, statsd.Gather(&acc))
 
 		if len(acc.Metrics) > 0 {
 			break
@@ -1832,14 +1633,13 @@ func TestUdp(t *testing.T) {
 	defer statsd.Stop()
 
 	conn, err := net.Dial("udp", "127.0.0.1:14223")
+	require.NoError(t, err)
 	_, err = conn.Write([]byte("cpu.time_idle:42|c\n"))
 	require.NoError(t, err)
-	err = conn.Close()
-	require.NoError(t, err)
+	require.NoError(t, conn.Close())
 
 	for {
-		err = statsd.Gather(&acc)
-		require.NoError(t, err)
+		require.NoError(t, statsd.Gather(&acc))
 
 		if len(acc.Metrics) > 0 {
 			break
@@ -1864,3 +1664,12 @@ func TestUdp(t *testing.T) {
 		testutil.IgnoreTime(),
 	)
 }
+
+func TestParse_Ints(t *testing.T) {
+	s := NewTestStatsd()
+	s.Percentiles = []Number{90}
+	acc := &testutil.Accumulator{}
+
+	require.NoError(t, s.Gather(acc))
+	require.Equal(t, s.Percentiles, []Number{90.0})
+}
